@@ -14,8 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
-from calculate.consolegui import qt
+from .. import qt
 from .more import ButtonMenu, icon_visible, LabelWordWrap, get_sid, show_msg, \
                  ClientServiceThread, show_question, get_view_params, _print, \
     get_system_rgb, dpivalue
