@@ -122,11 +122,10 @@ class AddServerCert (qt.QDialog):
         self.grid.addWidget(LabelWordWrap(_('Untrusted Server Certificate!'), \
                                                             self), 0, 1, 1, 2)
 
-        #TODO check if digest / get_serial_number return str or bytes
         certobj = OpenSSL.crypto.load_certificate \
                     (OpenSSL.SSL.FILETYPE_PEM, cert)
         self.grid.addWidget(LabelWordWrap (_('Fingerprint = %s') \
-                            % certobj.digest('SHA1'), self), 1, 0, 1, 3)
+                            % certobj.digest('SHA1').decode("UTF-8"), self), 1, 0, 1, 3)
         self.grid.addWidget(LabelWordWrap (_('Serial Number =  %s') \
                             % certobj.get_serial_number(), self), 2, 0, 1, 3)
 
@@ -136,9 +135,9 @@ class AddServerCert (qt.QDialog):
         self.issuer_layout = qt.QVBoxLayout()
 
         Issuer = certobj.get_issuer().get_components()
-        for i in Issuer:
+        for item in Issuer:
             self.issuer_layout.addWidget(LabelWordWrap \
-                                                ("%s : %s" %(i[0], i[1]),self))
+                                                ("%s : %s" %(item[0].decode("UTF-8"), item[1].decode("UTF-8")),self))
 
         self.issuer_wgt.setLayout(self.issuer_layout)
         self.tab.addTab(self.issuer_wgt, _('Issuer'))
