@@ -14,10 +14,9 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
 import os
 
-from calculate.consolegui import qt
+from .. import qt
 
 from .more import LabelWordWrap, FileOpenWgt, show_msg, show_question, \
                  client_list_methods, get_icon, dpivalue
